==> ros-rolling-fastrtps_2.10.1.orig.tar.gz: ros-rolling-fastrtps-2.10.1/roadmap.md <==
# Fast DDS Roadmap

This product is a FIWARE Generic Enabler.
If you would like to learn about the overall Roadmap of FIWARE, please check section "Roadmap" on the FIWARE Catalogue.

## Introduction

This section elaborates on proposed new features or tasks which are expected to be added to the product in the
foreseeable future.
There should be no assumption of a commitment to deliver these features on specific dates or in the order given.
The development team will be doing their best to follow the proposed dates and priorities, but please bear in mind
that plans to work on a given feature or task may be revised.
All information is provided as a general guidelines only, and this section may be revised to provide newer information
at any time.

Disclaimer:

* This section has been last updated in December 2022.
  Please take into account its content could be obsolete.

## Short term

The following list of features are planned to be addressed in the short term, and incorporated into the following
minor release of the product:

* Complete support for dynamic network interfaces
* XML generation tool
* DDS-XTypes 1.3
* Monitor service to keep track of discovery events.
* Tier 1 support for QNX platforms.

## Medium term

The following list of features are planned to be addressed in the medium term, typically within the subsequent
release(s) generated in the next **9 months** after next planned release:

* Support for Time-based filter QoS
* Service aware DataWriter
* Thread configuration QoS.

## Long term

The following list of features are proposals regarding the longer-term evolution of the product even though development
of these features has not yet been scheduled for a release in the near future.
Please feel free to contact us if you wish to get involved in the implementation or influence the roadmap.

* Full DDS API compliance
* Compliance with DDS-XML
* Low bandwidth transports

==> ros-rolling-fastrtps_2.13.2.orig.tar.gz: ros-rolling-fastrtps-2.13.2/roadmap.md <==
# Fast DDS Roadmap

This product is a FIWARE Generic Enabler.
If you would like to learn about the overall Roadmap of FIWARE, please check section "Roadmap" on the FIWARE Catalogue.

## Introduction

This section elaborates on proposed new features or tasks which are expected to be added to the product in the
foreseeable future.
There should be no assumption of a commitment to deliver these features on specific dates or in the order given.
The development team will be doing their best to follow the proposed dates and priorities, but please bear in mind
that plans to work on a given feature or task may be revised.
All information is provided as a general guidelines only, and this section may be revised to provide newer information
at any time.

Disclaimer:

* This section has been last updated in October 2023.
  Please take into account its content could be obsolete.

## Short term

The following list of features are planned to be addressed in the short term, and incorporated into the following
minor release of the product:

* DDS-XTypes 1.3
* Ignore local endpoints configured at endpoint level
* Refactor whitelist feature to allowed and blocked network interfaces
* Extend network interfaces to enable mask filtering
* Complete support for dynamic network interfaces

## Medium term

The following list of features are planned to be addressed in the medium term, typically within the subsequent
release(s) generated in the next **9 months** after next planned release:

* Tier 1 support for QNX platforms
* Tier 1 support for Android platforms
* Support for Time-based filter QoS
* Service aware DataWriter

## Long term

The following list of features are proposals regarding the longer-term evolution of the product even though development
of these features has not yet been scheduled for a release in the near future.
Please feel free to contact us if you wish to get involved in the implementation or influence the roadmap.

* Full DDS API compliance
* Compliance with DDS-XML
* Low bandwidth transports
